#include <SimpleDHT.h>
#include <TinyGPS.h>

#define pin_plus 10
#define pin_fire 11

int pinDHT22 = 12;
SimpleDHT22 dht22(pinDHT22);
TinyGPS gps; // create gps object
int counter = 10;  //Starting with display off
int increase = LOW;

//Pairing pins with segments
const int pins[7] = { 24, 22, 34, 32, 30, 26, 28 }; 
//                     a   b   c   d   e   f   g
//const int pins[7] = { 26, 28, 34, 32, 30, 24, 22 }; 
//                     a   b   c   d   e   f   g

//Setting the numbers
const byte numbersDisplayAnode[11] = {0b1000000,    //0
                          0b1111001,                //1
                          0b0100100,                //2
                          0b0110000,                //3
                          0b0011001,                //4
                          0b0010010,                //5
                          0b0000010,                //6
                          0b1111000,                //7
                          0b0000000,                //8
                          0b0010000,                //9
                          0b1111111};               //off

char action;
char id;
int this_id = 0;
float temperature = 0;
float humidity = 0;
float latitude = 0;
float longitude = 0;

void setup()
{
  Serial.begin(9600);  // make sure serial monitor is set to this rate
  Serial2.begin(9600); // change this to the rate set in rf magic.
  Serial3.begin(9600); // GPS serial port
    
  //Set pins 22-34 every two to OUTPUT
  for(int i = 0; i < 7; i++) {
    pinMode(pins[i], OUTPUT);  
  }

  //Set pin 12 to INPUT
  pinMode(pin_plus, INPUT);

  //Set pin 10 to OUTPUT
  pinMode(pin_fire, OUTPUT);
    
  //Starting with the display off
  lightSegments(10);

}

void loop()
{
  increase = digitalRead(pin_plus);

  // Reading instructions for the display
  if (increase == HIGH) {
    if (counter == 10) {
      counter = 0;
    }
    else {
      counter++;
    }
    //Serial.print("counter: ");
    //Serial.println(counter);
    lightSegments(counter);
  }
  
  this_id = counter;

  // Reading temperature and humidity
  dht22.read2(&temperature, &humidity, NULL);
  
  // Reading GPS coordinates
  while(Serial3.available()){
    if(gps.encode(Serial3.read())){
      gps.f_get_position(&latitude,&longitude);
    }
  }
  
  if(Serial2.available())
  {
    id = Serial2.read();
    action = Serial2.read();
    if (this_id == int(id)-48){
      switch (action) {
        case '1':
          Serial2.print("Temperature: ");
          Serial2.println((float)temperature);
          Serial2.print("Humidity: ");
          Serial2.println((float)humidity);
          break;
        case '2':
          Serial2.print("Latitude: ");
          Serial2.println(latitude, 5);
          Serial2.print("Longitude: ");
          Serial2.println(longitude, 5);
          break;
        case '3':
          Serial2.println("fire");
          digitalWrite(pin_fire, HIGH);
          delay(2000);
          digitalWrite(pin_fire, LOW);
          break;
        default:
          break;
      }  
    }
    Serial2.flush();
  }
  delay(200);
}

//Function to set the number in the display
void lightSegments(int number) {
  byte numberBit = numbersDisplayAnode[number];
  for (int i = 0; i < 7; i++)  {
    int bit = bitRead(numberBit, i);
    digitalWrite(pins[i], bit);
  }
}
